==> pp_project_pkg-1.0.202307061234-py3-none-any.whl: mlflow_pipelines/run_mlflow.py <==
import mlflow
import os
import wandb
import hydra
from omegaconf import DictConfig


@hydra.main(config_path='mlflow_pipelines',config_name='config.yaml')
def go(config: DictConfig):

    os.environ["WANDB_PROJECT"] = config["main"]["project_name"]
    os.environ["WANDB_RUN_GROUP"] = config["main"]["experiment_name"]

    root_path = hydra.utils.get_original_cwd()
    print(config)

    _ = mlflow.run(
        os.path.join(root_path, "./fetch_data"),
        "run_mlflow",
        parameters={
            "site_id": config["data"]["site_res"],
            "date" : config["data"]["start_date"],
            "logger" : config["data"]["logger"],
            "artifact_name": "upload_file.csv",
            "artifact_type": "fetch_upload_data_file",
            "artifact_description": "Fetching the data which has been uploaded in the DB"
        },
    )

    _ = mlflow.run(
        os.path.join(root_path, "mlflow_pipelines/upload_data"),
        "run_mlflow",
        parameters={
            "input_artifact": "to_upload.csv:latest",
            "artifact_name": "uploaded_data.csv",
            "artifact_type": "processed_data",
            "artifact_description": "uploading all the data to the DB"
        },
        
    _ = mlflow.run(
        os.path.join(root_path, "mlflow_pipelines/train_model"),
        "run_mlflow",
        parameters={
            "input_artifact": "clean_data.csv:latest",
            "artifact_name": "model.pkl",
            "artifact_type": "model",
            "artifact_description": "Trained model"
        },
    )
    )

if __name__ == "__main__":
    go()

==> pp_project_pkg-1.0.202307061238-py3-none-any.whl: mlflow_pipelines/run_mlflow.py <==
import mlflow
import os
import wandb
import hydra
from omegaconf import DictConfig


#@hydra.main(config_path='mlflow_pipelines',config_name='config.yaml')
@hydra.main(config_name='config.yaml')
def go(config: DictConfig):

    os.environ["WANDB_PROJECT"] = config["main"]["project_name"]
    os.environ["WANDB_RUN_GROUP"] = config["main"]["experiment_name"]

    root_path = hydra.utils.get_original_cwd()
    print(config)

    _ = mlflow.run(
        os.path.join(root_path, "./fetch_data"),
        "run_mlflow",
        parameters={
            "site_id": config["data"]["site_res"],
            "date" : config["data"]["start_date"],
            "logger" : config["data"]["logger"],
            "artifact_name": "upload_file.csv",
            "artifact_type": "fetch_upload_data_file",
            "artifact_description": "Fetching the data which has been uploaded in the DB"
        },
    )

    _ = mlflow.run(
        os.path.join(root_path, "mlflow_pipelines/upload_data"),
        "run_mlflow",
        parameters={
            "input_artifact": "to_upload.csv:latest",
            "artifact_name": "uploaded_data.csv",
            "artifact_type": "processed_data",
            "artifact_description": "uploading all the data to the DB"
        },
        
    _ = mlflow.run(
        os.path.join(root_path, "mlflow_pipelines/train_model"),
        "run_mlflow",
        parameters={
            "input_artifact": "clean_data.csv:latest",
            "artifact_name": "model.pkl",
            "artifact_type": "model",
            "artifact_description": "Trained model"
        },
    )
    )

if __name__ == "__main__":
    go()
